FormFieldModel<T, S> class

Constructors

FormFieldModel({required TypeFieldEnum type, required String fieldKey, required String label, required TextEditingController controller, String? messageError, TextInputType? keyboardType, ValidationTypeEnum? validationType, String? formatDateTime, int? minDate, DateTime? lastDate, List<S>? itemList, S? toMapModel, S? valueSelected})

Properties

controller TextEditingController
final
fieldKey String
final
formatDateTime String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
itemList List<S>?
getter/setter pair
keyboardType TextInputType?
getter/setter pair
label String
final
lastDate DateTime?
getter/setter pair
messageError String?
getter/setter pair
minDate int?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toMapModel ↔ S?
getter/setter pair
type TypeFieldEnum
final
validationType ValidationTypeEnum?
getter/setter pair
valueSelected ↔ S?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited